summaryrefslogtreecommitdiff
path: root/framework/source/inc/loadenv/loadenvexception.hxx
diff options
context:
space:
mode:
Diffstat (limited to 'framework/source/inc/loadenv/loadenvexception.hxx')
-rw-r--r--framework/source/inc/loadenv/loadenvexception.hxx4
1 files changed, 2 insertions, 2 deletions
diff --git a/framework/source/inc/loadenv/loadenvexception.hxx b/framework/source/inc/loadenv/loadenvexception.hxx
index b3ea775857..ee666d0d02 100644
--- a/framework/source/inc/loadenv/loadenvexception.hxx
+++ b/framework/source/inc/loadenv/loadenvexception.hxx
@@ -58,7 +58,7 @@ namespace css = ::com::sun::star;
load environment only.
@descr Of course outside code must wrapp it, to transport
- the occured information to its caller.
+ the occurred information to its caller.
@author as96863
*/
@@ -133,7 +133,7 @@ class LoadEnvException
/** @short An ID, which make this exception unique among others. */
sal_Int32 m_nID;
/** @short Contains the original exception, if any occured. */
css::uno::Any m_exOriginal;
/** TODO
@@ -133,7 +133,7 @@ class LoadEnvException
/** @short An ID, which make this exception unique among others. */
sal_Int32 m_nID;
- /** @short Contains the original exception, if any occured. */
+ /** @short Contains the original exception, if any occurred. */
css::uno::Any m_exOriginal;
/** TODO